<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK" sourcelanguage="en">
<context>
    <name>Converter</name>
    <message>
        <location filename="../src/converter.cpp" line="92"/>
        <location filename="../src/converter.cpp" line="99"/>
        <location filename="../src/converter.cpp" line="106"/>
        <source>Error: %1</source>
        <translation>Fejl: %1</translation>
    </message>
</context>
<context>
    <name>DialogConversionStatus</name>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="14"/>
        <source>Status...</source>
        <translation>Status...</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="20"/>
        <source>Conversion Status</source>
        <translation>Konverteringsstatus</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="46"/>
        <source>Image:</source>
        <translation>Billede:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="51"/>
        <source>Status:</source>
        <translation>Status:</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="70"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Total:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Totalt:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="81"/>
        <location filename="../ui/dialogconversionstatus.ui" line="116"/>
        <location filename="../ui/dialogconversionstatus.ui" line="151"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="105"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Converted:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Konverteret:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="140"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Errors:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fejl:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="191"/>
        <source>Open destination </source>
        <translation>Åbn destination</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="211"/>
        <source>Stop</source>
        <translation>Stop</translation>
    </message>
    <message>
        <location filename="../ui/dialogconversionstatus.ui" line="218"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="41"/>
        <source>Open all the destination folders</source>
        <translation>Åbn alle destinations mapper</translation>
    </message>
    <message>
        <location filename="../src/dialogconversionstatus.cpp" line="75"/>
        <source>Converted</source>
        <translation>Konverteret</translation>
    </message>
</context>
<context>
    <name>DialogInfo</name>
    <message>
        <location filename="../ui/dialoginfo.ui" line="20"/>
        <source>About Converseen...</source>
        <translation>Om Converseen...</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="73"/>
        <source>Informations</source>
        <translation>Informationer</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="95"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Translators:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Oversættere:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="130"/>
        <source>&lt;strong&gt;Hungarian translation: &lt;/strong&gt;Charles Barcza - &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Ungarnsk- oversættelse:: &lt;/strong&gt;Charles Barcza - &lt;a href=&quot;mailto:kbarcza@blackpanther.hu&quot;&gt;kbarcza@blackpanther.hu&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="137"/>
        <source>&lt;strong&gt;Czech translation: &lt;/strong&gt;Pavel Fric - &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Tjekkisk oversættelse: &lt;/strong&gt;Pavel Fric - &lt;a href=&quot;mailto:pavelfric@seznam.cz&quot;&gt;pavelfric@seznam.cz&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="161"/>
        <source>&lt;strong&gt;German Translation: &lt;/strong&gt;Marco Nickolai - &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Tysk oversættelse: &lt;/strong&gt;Marco Nickolai - &lt;a href=&quot;mailto:nickolai@iad.tu-darmstadt.de&quot;&gt;nickolai@iad.tu-darmstadt.de&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="168"/>
        <source>&lt;strong&gt;Spanish (Chile) Translation: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;
</source>
        <translation>&lt;strong&gt;Spansk-(Chiliensk) oversættelse: &lt;/strong&gt;Nelson Álvarez Sáez - &lt;a href=&quot;mailto:alvareznelson@gmail.com&quot;&gt;alvareznelson@gmail.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="176"/>
        <source>&lt;strong&gt;Turkish Translation: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt;
</source>
        <translation>&lt;strong&gt;Tyrkisk oversættelse: &lt;/strong&gt;Zeugma - &lt;a href=&quot;mailto:sunder67@hotmail.com&quot;&gt;sunder67@hotmail.com&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="184"/>
        <source>&lt;strong&gt;Russian Translation: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Russisk oversættelse: &lt;/strong&gt;Stasik Savorovsky - &lt;a href=&quot;mailto:stas_stv@mail.ru&quot;&gt;stas_stv@mail.ru&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="191"/>
        <source>&lt;strong&gt;Polish Translation: &lt;/strong&gt;Michał Olber from OSWorld.pl - &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</source>
        <translation>&lt;strong&gt;Polsk oversættelse: &lt;/strong&gt;Michał Olber from OSWorld.pl - &lt;a href=&quot;mailto:redakcja@osworld.pl&quot;&gt;redakcja@osworld.pl&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="215"/>
        <source>&lt;strong&gt;Ukrainian translation: &lt;/strong&gt;AleXKaN - &lt;a href=&quot;mailto:aws2@india.com&quot;&gt;aws2@india.com&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="44"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="79"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Author: &lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Francesco Mondello (Faster) - &lt;/span&gt;&lt;a href=&quot;http://fasterland.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Email: &lt;/span&gt;&lt;a href=&quot;faster3ck@gmail.com&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; &quot;&gt;faster3ck@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Project Website: &lt;/span&gt;&lt;a href=&quot;http://converseen.fasterland.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;converseen.fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Ophav: &lt;/span&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Francesco Mondello (Faster) - &lt;/span&gt;&lt;a href=&quot;http://fasterland.net/&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;E-mail: &lt;/span&gt;&lt;a href=&quot;faster3ck@gmail.com&quot;&gt;&lt;span style=&quot; font-size:10pt; text-decoration: underline; &quot;&gt;faster3ck@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt; font-weight:600;&quot;&gt;Projekt-websted: &lt;/span&gt;&lt;a href=&quot;http://converseen.fasterland.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;converseen.fasterland.net&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="144"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;French Translation: &lt;/span&gt;Adrien DAUGABEL &lt;a href=&quot;mailto:adrien.d@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;adrien.d@mageialinux-online.org - &lt;/span&gt;&lt;/a&gt;David GEIGER &lt;a href=&quot;mailto:david.david@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;david.david@mageialinux-online.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Fransk oversættelse: &lt;/span&gt;Adrien DAUGABEL &lt;a href=&quot;mailto:adrien.d@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;adrien.d@mageialinux-online.org - &lt;/span&gt;&lt;/a&gt;David GEIGER &lt;a href=&quot;mailto:david.david@mageialinux-online.org&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;david.david@mageialinux-online.org&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="151"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Brazilian Portuguese Translation: &lt;/span&gt;Paulo Guzmán - &lt;a href=&quot;mailto:white.hat@msn.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;white.hat@msn.com&lt;/span&gt;&lt;/a&gt; -&lt;span style=&quot; font-weight:600;&quot;/&gt;Márcio Moraes - &lt;a href=&quot;mailto:marciopanto@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;marciopanto@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Brasiliensk Portugisisk oversættelse: &lt;/span&gt;Paulo Guzmán - &lt;a href=&quot;mailto:white.hat@msn.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;white.hat@msn.com&lt;/span&gt;&lt;/a&gt; -&lt;span style=&quot; font-weight:600;&quot;/&gt;Márcio Moraes - &lt;a href=&quot;mailto:marciopanto@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;marciopanto@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="201"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Japanese translation:&lt;/span&gt; Xenolith0 - &lt;a href=&quot;mailto:xenolith0bytetestcomgreen@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;xenolith0bytetestcomgreen@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Japansk oversættelse: &lt;/span&gt; Xenolith0 - &lt;a href=&quot;mailto:xenolith0bytetestcomgreen@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;xenolith0bytetestcomgreen@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Danish translation: &lt;/span&gt;Martin Eilsoe - &lt;a href=&quot;mailto:martin.eilsoe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;martin.eilsoe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dansk oversættelse: &lt;/span&gt;Martin Eilsoe - &lt;a href=&quot;mailto:martin.eilsoe@gmail.com&quot;&gt;&lt;span style=&quot; text-decoration: underline; &quot;&gt;martin.eilsoe@gmail.com&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="231"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;If you appreciate this work and would like to support the project, you are welcome to donate via PayPal&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="291"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Follow Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;Følg Converseen:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="53"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseen is an image batch conversion tool. You can resize and convert images in more than 100 different formats.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;MS Shell Dlg 2&apos;; font-size:8.25pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:10pt;&quot;&gt;Converseeen er et billede konverteringsværktøj. Du kan tilpasse størrelser og konvertere imellem mere end 100 forskellige formater.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="368"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;;&quot;&gt;(c) 2009 - 2018 Francesco Mondello GNU - GPL v.3&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Noto Sans&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-family:&apos;MS Shell Dlg 2&apos;;&quot;&gt;(c) 2009 - 2017 Francesco Mondello GNU - GPL v.3&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt; {3C?} {4.0/?} {3.?} {40/?} {1&quot;?} {10p?} {400;?} {0p?} {0p?} {0p?} {0p?} {0;?} {0p?} {2&apos;?} {2009 ?} {2018 ?} {3&lt;?}</translation>
    </message>
    <message>
        <location filename="../ui/dialoginfo.ui" line="394"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../src/dialoginfo.cpp" line="50"/>
        <source>The batch image converter and resizer.</source>
        <translation>Batch billede konvertering og størrelse tilpasning.</translation>
    </message>
</context>
<context>
    <name>DialogMultipageEditor</name>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="14"/>
        <source>Import multipage document</source>
        <translation>Importér flere dokumenter</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="20"/>
        <source>Check the pages or subimages you want to import</source>
        <translation>Check siderne eller underbillederne du ønsker at importere</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="42"/>
        <source>Page</source>
        <translation>Side</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="47"/>
        <source>Pixel size</source>
        <translation>pixelstørrelse</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="52"/>
        <source>Density</source>
        <translation>Tæthed</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="57"/>
        <source>Depth</source>
        <translation>Dybde</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="80"/>
        <source>Cancel</source>
        <translation>Annullér</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="91"/>
        <source>Import</source>
        <translation>Importér</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="108"/>
        <source>Check</source>
        <translation>Markér</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="117"/>
        <source>Check all</source>
        <translation>Markér alle</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="126"/>
        <source>Uncheck</source>
        <translation>Afmarkér</translation>
    </message>
    <message>
        <location filename="../ui/dialogmultipageeditor.ui" line="135"/>
        <source>Uncheck all</source>
        <translation>Afmarkér alle</translation>
    </message>
</context>
<context>
    <name>DialogOptions</name>
    <message>
        <location filename="../ui/dialogoptions.ui" line="14"/>
        <source>Settings</source>
        <translation>Indstillinger</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="20"/>
        <source>Language</source>
        <translation>Sprog</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="26"/>
        <source>Language:</source>
        <translation>Sprog:</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="46"/>
        <source>Overwriting settings</source>
        <translation>Overskriv</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="52"/>
        <source>As&amp;k first</source>
        <translation>Spør&amp;g først</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="62"/>
        <source>O&amp;verwrite all existing images</source>
        <translation>O&amp;verskriv eksisterende billeder</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="72"/>
        <source>Updates</source>
        <translation>Opdateringer</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="78"/>
        <source>Checks for updates automatically</source>
        <translation>Automatisk check for opdateringer</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="103"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../ui/dialogoptions.ui" line="110"/>
        <source>Cancel</source>
        <translation>Annullér</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="61"/>
        <source>Warning!</source>
        <translation>Advarsel!</translation>
    </message>
    <message>
        <location filename="../src/dialogoptions.cpp" line="62"/>
        <source>Please, restart Converseen to apply current language!</source>
        <translation>Genstart programmet Converseen for at aktivere valgte sprog!</translation>
    </message>
</context>
<context>
    <name>DialogQuality</name>
    <message>
        <location filename="../ui/dialogquality.ui" line="14"/>
        <source>Image settings</source>
        <translation>Billedindstillinger</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="20"/>
        <source>Jpeg compression level</source>
        <translation>JPEG-Kompressionsgrad</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="28"/>
        <location filename="../ui/dialogquality.ui" line="69"/>
        <source>Quality 0 - 100:</source>
        <translation>Kvalitet 0 - 100:</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="61"/>
        <source>Png compression level</source>
        <translation>PNG-Kompressionsgrad</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="99"/>
        <source>Interpolation</source>
        <translation>Interpolation</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="107"/>
        <source>Filter:</source>
        <translation>Filter:</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="147"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <location filename="../ui/dialogquality.ui" line="154"/>
        <source>Cancel</source>
        <translation>Annullér</translation>
    </message>
</context>
<context>
    <name>DialogShowUpdateMsg</name>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="14"/>
        <source>Dialog</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="20"/>
        <source>TextLabel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="40"/>
        <source>Don&apos;t show again</source>
        <translation>Vis ikke igen</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="62"/>
        <source>Update Now</source>
        <translation>Opdatér</translation>
    </message>
    <message>
        <location filename="../ui/dialogshowupdatemsg.ui" line="69"/>
        <source>Not Now</source>
        <translation>Ikke nu</translation>
    </message>
</context>
<context>
    <name>Formats</name>
    <message>
        <location filename="../src/formats.cpp" line="90"/>
        <source>All Supported Filters (%1)</source>
        <translation>Alle understøttede formater (%1)</translation>
    </message>
    <message>
        <location filename="../src/formats.cpp" line="112"/>
        <source>Don&apos;t change the format</source>
        <translation>Ændre ikke formatet</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../ui/mainwindow.ui" line="32"/>
        <source>Converseen</source>
        <translation>Converseen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="54"/>
        <source>Conversion Formats</source>
        <translation>Konverteringsformater</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="62"/>
        <source>Convert to:</source>
        <translation>Konverter til:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="96"/>
        <source>Show image settings dialog...</source>
        <translation>Vis billedindstillinger dialog...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="99"/>
        <source>Images settings</source>
        <translation>Billedindstillinger</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="161"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="166"/>
        <source>&amp;Edit</source>
        <translation>&amp;Redigér</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="171"/>
        <source>&amp;Actions</source>
        <translation>&amp;Handlinger</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="176"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjælp</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="247"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Preview:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Forhåndsvisning:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="355"/>
        <source>Show preview</source>
        <translation>Vis forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="409"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Type:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Type:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="420"/>
        <location filename="../ui/mainwindow.ui" line="446"/>
        <location filename="../ui/mainwindow.ui" line="472"/>
        <location filename="../ui/mainwindow.ui" line="498"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt; - &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt; - &lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="435"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;File size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Filstørrelse:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="461"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image size:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Billedstørrelse:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="487"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Image resolution:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;right&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; color:#828282;&quot;&gt;Billedopløsning:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="523"/>
        <source>Dimensions</source>
        <translation>Dimensioner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="557"/>
        <source>Width:</source>
        <translation>Bredde:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="564"/>
        <source>Height:</source>
        <translation>Højde:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="651"/>
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 pixel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:10pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p align=&quot;center&quot; style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt;&quot;&gt;0 x 0 Pixel&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="671"/>
        <source>Mantain aspect ratio</source>
        <translation>Fasthold aspektforholdet</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="130"/>
        <source>Replace transparent background</source>
        <translation>Erstat transparent baggrund</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="137"/>
        <source>Choose color</source>
        <translation>Vælg farve</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="207"/>
        <source>Actio&amp;ns Panel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="541"/>
        <source>Scale image</source>
        <translation>Skalér billede</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="664"/>
        <source>Link aspect with selected image</source>
        <translation>Link aspekt med valgte billede</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="692"/>
        <source>Resolution</source>
        <translation>Opløsning</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="708"/>
        <source>Resolution X:</source>
        <translation>Opløsning X:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="715"/>
        <source>Resolution Y:</source>
        <translation>Opløsning Y:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="754"/>
        <location filename="../ui/mainwindow.ui" line="760"/>
        <source>Rotate and flip</source>
        <translation>Rotér og spejlvend</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="775"/>
        <source>Rotate image:</source>
        <translation>Rotér billede:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="784"/>
        <source>No rotation</source>
        <translation>Ingen rotering</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="856"/>
        <source>Flip image:</source>
        <translation>Spejlvend billede:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="865"/>
        <source>No flip</source>
        <translation>Ingen spejlvending</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="883"/>
        <source>Horizontally</source>
        <translation>Horisontalt</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="897"/>
        <source>Vertically</source>
        <translation>Vertikalt</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="947"/>
        <source>Output options</source>
        <translation>Output valg</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="959"/>
        <source>Save in:</source>
        <translation>Gem i:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="971"/>
        <source>Open output directory</source>
        <translation>Åbn output  mappe</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="974"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="985"/>
        <source>Image&apos;s directory</source>
        <translation>Billedets mappe</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1014"/>
        <source>Rename:</source>
        <translation>Omdøb:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1023"/>
        <source>Prefi&amp;x/Suffix</source>
        <translation>Præfik&amp;s/suffiks</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1033"/>
        <source>Progressi&amp;ve Number</source>
        <translation>Progressi&amp;ve tal</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1050"/>
        <source>#_copy</source>
        <translation>#_Kopi</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1057"/>
        <source>Start with:</source>
        <translation>Start med:</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1086"/>
        <source>Overwrite all</source>
        <translation>Overskriv alt</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1115"/>
        <source>toolBar</source>
        <translation>Værktøjslinie</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1146"/>
        <source>&amp;Open images</source>
        <translation>&amp;Åbn billeder</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1149"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1158"/>
        <source>&amp;Add images</source>
        <translation>&amp;Tilføj billeder</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1161"/>
        <source>Ctrl+Alt+O</source>
        <translation>Ctrl+Alt+O</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1170"/>
        <source>&amp;Remove images</source>
        <translation>&amp;Fjern billeder</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1173"/>
        <source>Remove selected pictures</source>
        <translation>Fjern valgte billeder</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1176"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1185"/>
        <source>Remove &amp;all</source>
        <translation>Fjern &amp;alle</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1188"/>
        <source>Remove all pictures</source>
        <translation>Fjern alle billeder</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1191"/>
        <source>Alt+Del</source>
        <translation>Alt+Del</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1200"/>
        <source>&amp;Check</source>
        <translation>&amp;Markér</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1203"/>
        <source>Check selected items</source>
        <translation>Markér valgte emner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1206"/>
        <source>Ctrl+H</source>
        <translation>Ctrl+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1215"/>
        <source>Check a&amp;ll</source>
        <translation>Markér a&amp;lle</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1218"/>
        <source>Check all items</source>
        <translation>Markér alle emner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1221"/>
        <source>Ctrl+Alt+H</source>
        <translation>Ctrl+Alt+H</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1230"/>
        <source>&amp;Convert</source>
        <translation>&amp;Konvertér</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1233"/>
        <source>Start the conversion process</source>
        <translation>Start konverteringen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1236"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1241"/>
        <source>&amp;Settings</source>
        <translation>&amp;Indstillinger</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1244"/>
        <source>Open the settings dialog</source>
        <translation>Åbn indstillinger</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1249"/>
        <source>&amp;Exit</source>
        <translation>&amp;Afslut</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1252"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1257"/>
        <source>Uncheck all &amp;items</source>
        <translation>Afmarkér alle &amp;emner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1260"/>
        <source>Ctrl+Alt+J</source>
        <translation>Ctrl+Alt+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1265"/>
        <source>&amp;Uncheck Items</source>
        <translation>&amp;Afmarkér emner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1268"/>
        <source>Uncheck selected items</source>
        <translation>Afmarkér valgte emner</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1271"/>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1276"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1279"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1288"/>
        <source>&amp;Donate via Paypal</source>
        <translation>&amp;Donér via Paypal</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1291"/>
        <source>Donate via Paypal</source>
        <translation>Donér via Paypal</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1296"/>
        <source>&amp;Report bug...</source>
        <translation>&amp;Rapportér fejl...</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1314"/>
        <source>&amp;Check for updates</source>
        <translation>&amp;Check for opdateringer</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1317"/>
        <source>Check if a new version of Converseen is available</source>
        <translation>Check om der findes en nyere version af Converseen</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1301"/>
        <source>Import PDF file</source>
        <translation>Importér PDF fil</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="801"/>
        <source>+ &amp;90°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="815"/>
        <source>- 9&amp;0°</source>
        <translation type="unfinished">- 90° {9&amp;0°?}</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="831"/>
        <source>&amp;180°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1306"/>
        <source>Import windows icon (*.ico)</source>
        <translation>Importér Windows-icon (*.ico)</translation>
    </message>
    <message>
        <location filename="../ui/mainwindow.ui" line="1309"/>
        <source>Import windows icon (*.ico *.icon)</source>
        <translation>Importér Windows-icon (*.ico *.icon)</translation>
    </message>
</context>
<context>
    <name>MainWindowImpl</name>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="218"/>
        <source>Open Image</source>
        <translation>Åbn billede</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="315"/>
        <location filename="../src/mainwindowimpl.cpp" line="321"/>
        <location filename="../src/mainwindowimpl.cpp" line="330"/>
        <location filename="../src/mainwindowimpl.cpp" line="334"/>
        <location filename="../src/mainwindowimpl.cpp" line="338"/>
        <source>Warning</source>
        <translation>Advarsel</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="335"/>
        <source>No image checked!</source>
        <translation>Ingen billeder er markeret!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="339"/>
        <source>No images to convert!</source>
        <translation>Ingen billeder at konvertere!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="316"/>
        <source>The output directory doesn&apos;t exists! Would you create it?</source>
        <translation>Output-mappen eksisterer ikke.! Ønsker du at oprette den?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="230"/>
        <source>Open Icon file</source>
        <translation>Åbn icon fil</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="230"/>
        <source>Microsoft icon (*.ico *.icon)</source>
        <translation>Microsoft icon (*.ico *.icon)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="241"/>
        <source>Open Pdf file</source>
        <translation>Åbn PDF fil</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="241"/>
        <source>Portable Document Format (*.pdf)</source>
        <translation>Portable Document Format (*.pdf)</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="251"/>
        <source>Analyzing the file. It may take a while, please wait...</source>
        <translation>Analyserer filen. Det kan tage lidt tid. Vent venligst...</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="322"/>
        <source>The directory cannot be created!</source>
        <translation>mappen kan ikke oprettes!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="331"/>
        <source>Set an output directory!</source>
        <translation>Angiv en output-mappe!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="348"/>
        <source>Processing...</source>
        <translation>Behandler...</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="511"/>
        <source>Processing finished!</source>
        <translation>Behandling færdig!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="565"/>
        <source>Open Directory</source>
        <translation>Åbn mappe</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="804"/>
        <location filename="../src/mainwindowimpl.cpp" line="862"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="935"/>
        <source>Suggest a new name!</source>
        <translation>Foreslå et nyt navn!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="936"/>
        <source>New name:</source>
        <translation>Nyt navn:</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="941"/>
        <source>Please, specify a name!</source>
        <translation>Angiv venligst et navn!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="942"/>
        <source>You should specify a name.
Click Retry to specify a new name.
Click Ignore to cancel this operation.
Click Abort to cancel all operations.</source>
        <translation>Du skulle angive et navn.
Klik &quot;Prøv igen&quot; og angiv et ny navn.
Klik &quot;Ignorér&quot; for at annullere denne operation.
Klik &quot;Afbryd&quot; for at annullere alle operationer.</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="957"/>
        <location filename="../src/mainwindowimpl.cpp" line="962"/>
        <source>Warning!</source>
        <translation>Advarsel!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="958"/>
        <source>The filename should not be empty!</source>
        <translation>Filnavnet skal ikke være tomt!</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="963"/>
        <source>The name chosen is identical to the initial one. Do you want to overwrite the original file?</source>
        <translation>Det valgte navn er identisk med det originale. Ønsker du at overskrive den originale fil?</translation>
    </message>
    <message>
        <location filename="../src/mainwindowimpl.cpp" line="979"/>
        <source>Aborted!</source>
        <translation>Afbrudt!</translation>
    </message>
</context>
<context>
    <name>PixTreeWidget</name>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="40"/>
        <source>To convert</source>
        <translation>Konverteres</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="41"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="42"/>
        <source>File name</source>
        <translation>Filnavn</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="43"/>
        <source>Image type</source>
        <translation>Billedtype</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="44"/>
        <source>File size</source>
        <translation>Filstørrelse</translation>
    </message>
    <message>
        <location filename="../src/pixtreewidget.cpp" line="45"/>
        <source>File path</source>
        <translation>Filplacering</translation>
    </message>
</context>
<context>
    <name>Translator</name>
    <message>
        <location filename="../src/translator.cpp" line="75"/>
        <location filename="../src/translator.cpp" line="88"/>
        <source>English</source>
        <translation>Dansk</translation>
    </message>
</context>
<context>
    <name>UpdateChecker</name>
    <message>
        <location filename="../src/updatechecker.cpp" line="72"/>
        <source>New version is available!</source>
        <translation>Ny version er tilgængelig!</translation>
    </message>
    <message>
        <location filename="../src/updatechecker.cpp" line="73"/>
        <source>A new version of %1 is available!
Would you download it?</source>
        <translation>En ny version af %1 er tilgængelig!
Ønsker du at downloade den?</translation>
    </message>
</context>
<context>
    <name>myLabelPreviewer</name>
    <message>
        <location filename="../src/mylabelpreviewer.cpp" line="50"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
</context>
</TS>
